@@ -2,11 +2,10 @@ from __future__ import annotations
 
 import inspect
 
-from matplotlib import docstring
-
 import mplhep
 
 from . import label as label_base
+from ._compat import docstring
 from .label import lumitext
 
 # Log styles
@@ -20,7 +19,7 @@ def text(text="", **kwargs):
     for key, value in dict(mplhep.rcParams.text._get_kwargs()).items():
         if (
             value is not None
-            and key not in kwargs.keys()
+            and key not in kwargs
             and key in inspect.getfullargspec(label_base.exp_text).kwonlyargs
         ):
             kwargs.setdefault(key, value)
@@ -32,7 +31,7 @@ def label(label=None, **kwargs):
     for key, value in dict(mplhep.rcParams.label._get_kwargs()).items():
         if (
             value is not None
-            and key not in kwargs.keys()
+            and key not in kwargs
             and key in inspect.getfullargspec(label_base.exp_label).kwonlyargs
         ):
             kwargs.setdefault(key, value)
